DocumentBuilder class

Builds a Document. Can be used fluently with cascades.

Constructors

DocumentBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Document
Finishes building and returns the created document.
embed(ParagraphEmbed embed) → void
Add an embed to the document.
line(void build(SpannedStringBuilder), [List<LineModifier>? modifiers = const []]) → void
Add a line of rich text to the document.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited