DocumentDeltaEncoder class

Encodes a document to a list of Quill delta insert operations.

Inheritance

Constructors

DocumentDeltaEncoder(Object? attributeEncoder(TextAttribute), Map<Type, EmbedEncoder<ParagraphEmbed>> embedEncoders)
Create an encoder.
const

Properties

attributeEncoder → Object? Function(TextAttribute)
Converts attributes to their value as a Quill delta attribute.
final
embedEncoders → Map<Type, EmbedEncoder<ParagraphEmbed>>
Maps embed keys to their encoder.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Document> stream) → Stream<List<Op>>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Document input) → List<Op>
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<List<Op>, TT> other) → Converter<Document, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<List<Op>> sink) → Sink<Document>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited