EmbedCodec<T extends ParagraphEmbed> class

Codec that can encode/decode the value of the embed with matching key.

Annotations

Constructors

EmbedCodec(String key, EmbedDecoder<T> decoder, EmbedEncoder<T> encoder)
Create an embed codec.
const

Properties

decoder → EmbedDecoder<T>
Decoder for the embed value.
final
embedType → Type
Runtime type of the embed this codec encodes and decodes to.
no setter
encoder → EmbedEncoder<T>
Encoder for the embed value.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
Object type in the delta format that can be decoded with decoder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited