OpJsonCodec class

Convert between an Op and a json object.

Inheritance

Constructors

OpJsonCodec()
Prefer using this constructor as constant. This codec is stateless so you can use a singleton.
const

Properties

decoder → Converter<Map<String, dynamic>, Op>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → Converter<Op, Map<String, dynamic>>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<Map<String, dynamic>, Op>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Map<String, dynamic> encoded) → Op
Decodes encoded data.
inherited
encode(Op input) → Map<String, dynamic>
Encodes input.
inherited
fuse<R>(Codec<Map<String, dynamic>, R> other) → Codec<Op, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited