DeleteOp class

A Quill delta delete operation.

Inheritance
Annotations

Constructors

DeleteOp(int length)
Create a delete operation.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
Number of characters to delete.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

deconstruct<S>({required S insert(String, BuiltMap<String, dynamic>), required S insertObject(String, Object, BuiltMap<String, dynamic>), required S retain(int, BuiltMap<String, dynamic>), required S delete(int)}) → S
Execute a function depending on the type of this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited