InsertOp class

A Quill delta operation that inserts formatted text.

Inheritance
Annotations

Constructors

InsertOp(String text, {Map<String, dynamic>? attributes})
Create an insert operation.

Properties

attributes → BuiltMap<String, Object>
Attributes applied to the text that determine formatting.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text → String
The plain text value.
final

Methods

copyWith({String? text, Map<String, Object>? attributes}) → InsertOp
Create a copy of this operation with the given fields replaced with the new values.
deconstruct<S>({required S insert(String, BuiltMap<String, Object>), required S insertObject(String, Object, BuiltMap<String, Object>), required S retain(int, BuiltMap<String, Object>), required S delete(int)}) → S
Execute a function depending on the type of this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited