LineModifierCodec<T extends LineModifier> class

Component codec for LineModifiers.

Inheritance

Constructors

LineModifierCodec.stateful({required String typeStr, required Object? encode(T), required T decode(Object?)})
Create a line modifier codec for a stateful line modifier.
const
LineModifierCodec.stateless({required String typeStr, required T create()})
Create a line modifier codec for a stateless line modifier.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
Type of the component that this codec can encode/decode.
no setterinherited
typeStr → String
String identifier used to find the codec to deserialize a component with.
finalinherited

Methods

decode(Object? value) → T
Decode the serialized state of a component to a T.
inherited
encode(T value) → Object?
Encode a component's state.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited