Op class abstract

Quill delta operation.

Implementers
Annotations

Constructors

Op.delete(int length)
Create a delete operation.
const
factory
Op.insert(String text, {Map<String, dynamic>? attributes})
Create an insert operation.
factory
Op.insertObject(String type, Map<String, dynamic>? value, {Map<String, dynamic>? attributes})
Create an insert operation that inserts an object.
factory
Op.retain(int length, {Map<String, dynamic>? attributes})
Create a retain operation.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

deconstruct<S>({required S insert(String, BuiltMap<String, dynamic>), required S insertObject(String, Object, BuiltMap<String, dynamic>), required S retain(int, BuiltMap<String, dynamic>), required S delete(int)}) → S
Execute a function depending on the type of this operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited