RetainOp class

A Quill delta retain operation. Can apply formatting over its length.

Inheritance
Annotations

Constructors

RetainOp(int length, {Map<String, dynamic>? attributes})
Create a retain operation.

Properties

attributes → BuiltMap<String, dynamic>
The attributes to apply over length.
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
How many UTF8 characters this operation applies to.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({int? length, Map<String, dynamic>? attributes}) → RetainOp
Create a copy of this operation with the given fields replaced with the new values.
deconstruct<S>({required S insert(String, BuiltMap<String, dynamic>), required S insertObject(String, Object, BuiltMap<String, dynamic>), required S retain(int, BuiltMap<String, dynamic>), required S delete(int)}) → S
Execute a function depending on the type of this operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited