toolbar_items library

Exposes ToolbarItems for the components in this package.

Properties

bold → ToolbarItem
Toolbar item that toggles the boldAttribute on the selected text.
final
bulletList → ToolbarItem
Toolbar item that toggles the bulletListModifier for the focused line.
final
italic → ToolbarItem
Toolbar item that toggles the italicAttribute on the selected text.
final
title ↔ ToolbarItem
Toolbar item that toggles the HeadingModifier with level 1 for the focused line.
getter/setter pair
underline → ToolbarItem
Toolbar item that toggles the underlineAttribute on the selected text.
final

Functions

createToggleableToolbarItem(String tooltip, TextAttribute attribute, IconData icon) → ToolbarItem
Helper function to easily create a toolbar item that toggles a specific attribute.
image({Future<ImageProvider<Object>?> pickImage(BuildContext)?, Future<ImageProvider<Object>?> snapImage(BuildContext)?}) → ToolbarItem
Create a toolbar item for inserting ImageEmbed.
Toolbar item that applies a LinkAttribute. Shows a dialog with a text field for the url.